@@ -14,7 +14,14 @@ import os
 
 name = 'telegram_util'
 
+def isprintable(s):
+    try: 
+    	s.encode('utf-8')
+    except UnicodeEncodeError: return False
+    else: return True
+
 def cutCaptionHtml(text, limit):
+	text = ''.join([c for c in text if isprintable(c)])
 	lines = text.split('\n')
 	lines = [line.strip() for line in lines]
 	text = '\n'.join(lines)
@@ -38,7 +45,7 @@ def removeOldFiles(dirname, day = 3):
 	count = 0 
 	for filename in os.listdir(dirname):
 		if os.path.getmtime(dirname + '/' + filename) < time.time() - 60 * 60 * 24 * day:
-			os.system('rm ' + dirname + '/' + filename)
+			os.system("rm '%s'" % (dirname + '/' + filename))
 			count += 1
 	return count
 
@@ -107,10 +114,12 @@ class AlbumResult(object):
 def compactText(text):
 	for _ in range(10):
 		text = text.replace('  ', ' ')
+		text = text.replace('\r', '\n')
 		text = text.replace('\n ', '\n')
 		text = text.replace(' \n', '\n')
 		text = text.replace('\xa0', ' ')
-	for _ in range(10):	
+	text = text.replace('\n', '\n\n')	
+	for _ in range(20):	
 		text = text.replace('\n\n\n', '\n\n')
 	return text.strip()
 
@@ -299,12 +308,20 @@ class TimedDeleter():
 		time_gap = min(self.queue[0][0] - time.time() + 30, 5 * 60)
 		threading.Timer(time_gap, lambda: self.process()).start() 
 
+def getMatchedKey(t, keys):
+	if not t:
+		return []
+	result = []
+	for key in keys:
+		if str(key).lower() in str(t).lower():
+			result.append(key)
+	return result
 
 def matchKey(t, keys):
 	if not t:
 		return False
 	for k in keys:
-		if k.lower() in t.lower():
+		if str(k).lower() in str(t).lower():
 			return True
 	return False
 
@@ -395,6 +412,16 @@ def clearUrl(url):
 		url = url.split('?')[0]
 	return url.strip('/')
 
+def getChannelsLog(channels):
+	result = []
+	for channel in channels:
+		if channel.id > 0:
+			result.append(getDisplayUserHtml(channel))
+		else:
+			result.append(getDisplayChatHtml(channel))
+	result.sort()
+	return 'channels: ' + ' '.join(result)
+
 def getBasicLog(msg):
 	result = ['id: %d' % msg.chat.id]
 	if msg.from_user:
@@ -411,3 +438,27 @@ def getOrigins(msg):
 	if msg.from_user:
 		result += [msg.from_user.id, msg.from_user.username]
 	return set([str(item) for item in result if item])
+
+def getTitleFromText(text):
+    text = text.strip().split('\n')[0].strip()
+    text = text.split('。')[0]
+    if text.startswith('【'):
+        new_text = text.split('】')[0][1:]
+        if len(new_text) > 5:
+            text = new_text
+    text = text.strip()
+    if text.endswith('source'):
+        text = text[:-6].strip()
+    if not text.startswith('【网评】'):
+        text = text.split('【网评】')[0]
+    if text.endswith('】') and text.startswith('【'):
+        text = text[1:-1]
+    if text.startswith('【'):
+        index = text.rfind('】')
+        if index != -1:
+            text = text[1 :index + 1] + '【' + text[index + 1:]
+    if text.endswith('】'):
+        index = text.find('【')
+        if index != -1:
+            text = text[:index] + '】' + text[index:-1] 
+    return text.replace('#', '')
\ No newline at end of file
